% OscillatorI2ab
% This program plots the voltage and current in an LC
% LC circuit 
% (a) as a function of time, (b) as a phase plot

% Lin = inductance (in mH)
% Cap = capacitance (in pF)
% Vamp = voltage amplitude (in volts)
% phi0 = phase offset

% Vplot = Voltage amplitudes for phase plot
% Nplot = number of phase plots

% Nosc = number of oscillations plotted
% Npoints = number of points in each period

% omega = radial oscillation frequency (in kHz)
% Iamp = current amplitude (in uA)

close all   %this clears previous figures

Lin = 1, Cap = 100, Vamp = 1; phi0 = 0,
L = Lin*1e-3; C = Cap*1e-12; om = 1/sqrt(L*C); 
Imp = sqrt(L/C); Ia = Vamp/Imp;
   % fundamental quantities in SI units
omega = 1e-6*om, %convert frequency to MHz.
Iamp = 1e6*Ia,  %convert current amplitude to uA

Nosc = 5, Npoints = 100, Ntot = Nosc*Npoints + 1;
   % set the plotting parameters
   
Nt = 1:Ntot; time = 2*pi*(Nt-1)/Npoints;
tphys = time/omega;  % physical time
   % set up the time arrays
   
Voltage = Vamp*cos(time + phi0);
Current = -Iamp*sin(time + phi0);
   % voltage and current as functions of time
   
subplot(2,1,1)
plot(tphys,Voltage)
title('Voltage')
xlabel ('time (\mus)')
ylabel ('Voltage (V)')

subplot(2,1,2)
plot(tphys,Current)
title('Current')
xlabel('time (\mus)')
ylabel('Current (\muA)')

Vplot=[0.5 0.7 0.9], Nplot=3,
% Set the values for the phase plots
figure
axis square
hold on
for Np=1:Nplot
    Vpl=Vplot(Np)*Voltage(1:Ntot);
    Ipl=Vplot(Np)*Current(1:Ntot);
    plot(Ipl,Vpl)
end
hold off
annotation('arrow','Position',[0.807,0.5,0,0.005])
text(150.0,0.8,'V_0=0.9')
annotation('arrow','Position',[0.743,0.5,0,0.005])
text(85.0,0.7,'V_0=0.7')
annotation('arrow','Position',[0.678,0.5,0,0.005])
text(10.0,0.55,'V_0=0.5')
title('Phase plot:  Voltage vs. Current')
xlabel('Current (\muA)')
ylabel ('Voltage (V)')
